#
# spec file for package distcc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           distcc
Version:        3.4
Release:        6.1
Summary:        A distributed C/C++ compiler
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/distcc/distcc
Source0:        https://github.com/distcc/distcc/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        distccd.sysconfig
Source2:        distccd.service
Patch3:         distcc-3.2_rc1-python.patch
# PATCH-FIX-UPSTREAM gh#distcc/distcc#493
Patch4:         use-setuptools-instead.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  binutils-devel
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(systemd)
Recommends:     %{name}-server = %{version}
Suggests:       %{name}-gui = %{version}

%description
distcc is a program to distribute builds of C, C++, Objective C or
Objective C++ code across several machines on a network, thereby
completing the task in less time. distcc should always generate the
same results as a local build.

%package gui
Summary:        GUI monitor for distcc server/client
Group:          Development/Tools/Building

%description gui
distcc is a program to distribute builds of C, C++, Objective C or
Objective C++ code across several machines on a network, thereby
completing the task in less time. distcc should always generate the
same results as a local build.

%package server
Summary:        Server for distributed C/C++ compilation
Group:          Development/Tools/Building
Requires:       %{name} = %{version}
%{?systemd_requires}

%description server
This package contains the compilation server needed to use %{name}.

%prep
%autosetup -p1

# do not use date/time in the c files
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i \
    -e "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" \
    src/daemon.c src/help.c lzo/minilzo.c

autoreconf -fvi

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
    --disable-Werror \
    --enable-rfc2553 \
    --with-gtk \
    --with-avahi \
    --with-auth
%make_build

%install
%make_install docdir=%{_docdir}/%{name}
# service
mkdir -p %{buildroot}/%{_sbindir}
ln -sf service %{buildroot}/%{_sbindir}/rc%{name}d
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/%{name}d.service
# sysconfig
install -Dm 644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.%{name}d
# compat links for env override
install -d %{buildroot}%{_libexecdir}/%{name}/bin
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/cc
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/gcc
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/g++
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/c++
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/cpp
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/clang
ln -sf %{_bindir}/%{name} %{buildroot}%{_libexecdir}/%{name}/bin/clang++

# pointless files
rm -rf %{buildroot}%{_docdir}/%{name}/{INSTALL,COPYING}
# cleanups
%suse_update_desktop_file -r distccmon-gnome Development Building
%fdupes %{buildroot}

%pre server
%service_add_pre distccd.service

%post server
%fillup_only -n distccd
%service_add_post distccd.service

%preun server
%service_del_preun distccd.service

%postun server
%service_del_postun distccd.service

%files
%license COPYING
%doc AUTHORS doc/* NEWS README.pump TODO README survey.txt
%dir %{_libexecdir}/distcc
%dir %{_libexecdir}/distcc/bin
%dir %{_docdir}/distcc
%{_libexecdir}/distcc/bin/c++
%{_libexecdir}/distcc/bin/cc
%{_libexecdir}/distcc/bin/cpp
%{_libexecdir}/distcc/bin/g++
%{_libexecdir}/distcc/bin/gcc
%{_libexecdir}/distcc/bin/clang
%{_libexecdir}/distcc/bin/clang++
%{_sbindir}/update-distcc-symlinks
%{_bindir}/distcc
%{_bindir}/distccmon-text
%{_bindir}/lsdistcc
%{_bindir}/pump
%{_mandir}/man1/distcc.1%{?ext_man}
%{_mandir}/man1/lsdistcc.1%{?ext_man}
%{_mandir}/man1/pump*
%{_mandir}/man1/distccmon-text.1%{?ext_man}
%dir %{_sysconfdir}/distcc
%config(noreplace) %{_sysconfdir}/%{name}/hosts

%files server
%license COPYING
%doc README
%{_bindir}/distccd
%{_unitdir}/distccd.service
%{_sbindir}/rcdistccd
%config(noreplace) %{_sysconfdir}/default/distcc
%config(noreplace) %{_sysconfdir}/distcc/*allow*
%{_mandir}/man1/distccd*
%{_mandir}/man1/include_server*
%{_fillupdir}/*
%{python3_sitearch}/include_server*

%files gui
%{_bindir}/distccmon-gnome
%{_datadir}/applications/distccmon-gnome.desktop
%{_datadir}/pixmaps/distccmon-gnome.png

%changelog
* Mon Mar 10 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-setuptools-instead.patch:
  * Use setuptools rather than distutils inside include_server.
* Mon Aug  8 2022 Dirk Müller <dmueller@suse.com>
- remove python2 dependency
* Thu May 12 2022 Dirk Müller <dmueller@suse.com>
- fix fdupes call
* Wed Oct  6 2021 Neil Brown <nfbrown@suse.com>
- Remove dependency on libgssglue.  It is no longer needed
  (bsc#1191068)
* Mon Sep 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * distccd.service
* Wed May 12 2021 Dirk Müller <dmueller@suse.com>
- update to 3.4:
  * distccmon-gnome ported from gtk2 to gtk3
  * Remove debug lag in spawning new threads. (better multi-core performance)
  * Bug fixes.
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 3.3.5:
  * Fix build on OSX
  * Fix build when using optional features AND those optional libraries decided
    to build against libsystemd (not sure which one, but it doesn't matter).
  * Python 3.8 compatibility issues
  * drop distcc-3.2_rc1-freedesktop.patch distcc-3.2_rc1-gssapi.patch: obsolete
  * drop gcc-10-no-common.patch: upstream
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- add gcc-10-no-common.patch:
  * Fixes link with gcc 10, upstream (https://github.com/distcc/distcc/pull/373)
* Mon Sep 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.3 bsc#1151594:
  * small fixes, such as fixing the build on some non-Linux systems
  * Fixes a regression where ssh mode did not work in most circumstances. Bug #291
- Rebase patch distcc-3.2_rc1-freedesktop.patch
* Tue Jul 23 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Sat May 19 2018 bjorn.lie@gmail.com
- Drop optional pkgconfig(libgnome-2.0) and
  pkgconfig(libgnomeui-2.0) BuildRequires and no longer pass
  - -enable-gnome to configure, gnome2 is long dead.
* Tue Mar 13 2018 jengelh@inai.de
- Ensure neutrality of description.
* Tue Mar 13 2018 avindra@opensuse.org
- Update to 3.3
  * Use masquerade as compiler white-list.
  * New --allow-private (the default) which allows non-global IP
    and IPv6 addresses.
  * Cross-compilation support.
  * Fix parsing of IPv6 addresses.
  * Python 3, not python 2.
  * Can build without python (and without pump mode or tests).
- cleanup with spec-cleaner
- use %%autosetup macro
- drop distcc-minilzo-2.08.patch (upstreamed)
- drop distcc-3.0-fix-fortify.patch (upstreamed)
- rebase distcc-3.2_rc1-freedesktop.patch
- rebase distcc-3.2_rc1-gssapi.patch
- rebase distcc-3.2_rc1-python.patch
- renumber patches
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Jun 14 2017 tchvatal@suse.com
- Switch to github distribution as the code.google.com is dead
- Drop the distcc-3.0-xinetd.patch as we do not install the service
  and user can tweak it up to his liking
* Fri Jan  9 2015 tchvatal@suse.com
- Fix typo in pre phase
* Thu Jan  8 2015 tchvatal@suse.com
- Fix license, GPL-2.0+
* Wed Dec 17 2014 tchvatal@suse.com
- Remember there is also clang for distcc
* Wed Dec 17 2014 tchvatal@suse.com
- Apply patch updating minilzo (taken from fedora):
  * distcc-minilzo-2.08.patch
- Wrong user setting in service file, we run it as root
* Mon Dec 15 2014 tchvatal@suse.com
- Run desktop_ macros on gui subpkg.
- Recommend server to be installed as you technically need it
  anyways.
* Thu Dec 11 2014 tchvatal@suse.com
- Apply patches from Gentoo to have same base:
  * distcc-3.0-fix-fortify.patch
  * distcc-3.0-xinetd.patch
  * distcc-3.2_rc1-freedesktop.patch
  * distcc-3.2_rc1-gssapi.patch
  * distcc-3.2_rc1-python.patch
* Thu Dec 11 2014 tchvatal@suse.com
- Add basic service, sysconfig and firewall rules:
  * distccd.sysconfig
  * distccd.service
  * distccd.firewall
* Thu Dec 11 2014 tchvatal@suse.com
- Add distcc distribute build tool for C and C++
